@@ -550,17 +550,17 @@ TkCanvPostscriptCmd(
 			(Tk_PostscriptInfo)psInfoPtr),
 		psInfo.x, Tk_PostscriptY((double)psInfo.y2,
 			(Tk_PostscriptInfo)psInfoPtr));
-	/*** waj ***/
-	Tcl_AppendPrintfToObj(psObj, "%g %g translate\n",
-		(Tk_PostscriptY((double) psInfo.x,(Tk_PostscriptInfo) &psInfo) -
-		 Tk_PostscriptY((double) psInfo.x2,(Tk_PostscriptInfo) &psInfo))
-		*(1.-psScale)/2.,
-		(Tk_PostscriptY((double) psInfo.y,(Tk_PostscriptInfo) &psInfo) -
-		 Tk_PostscriptY((double) psInfo.y2,(Tk_PostscriptInfo) &psInfo))
-		*(1.-psScale)/2.);
- 
-	Tcl_AppendPrintfToObj(psObj, "%.4g %.4g scale\n", psScale, psScale);
-	/*** waj ***/
+ 	/*** waj ***/
+ 	Tcl_AppendPrintfToObj(psObj, "%g %g translate\n",
+ 		(Tk_PostscriptY((double) psInfo.x,(Tk_PostscriptInfo) &psInfo) -
+ 		 Tk_PostscriptY((double) psInfo.x2,(Tk_PostscriptInfo) &psInfo))
+ 		*(1.-psScale)/2.,
+ 		(Tk_PostscriptY((double) psInfo.y,(Tk_PostscriptInfo) &psInfo) -
+ 		 Tk_PostscriptY((double) psInfo.y2,(Tk_PostscriptInfo) &psInfo))
+ 		*(1.-psScale)/2.);
+  
+ 	Tcl_AppendPrintfToObj(psObj, "%.4g %.4g scale\n", psScale, psScale);
+ 	/*** waj ***/
 	if (psInfo.chan != NULL) {
 	    if (Tcl_WriteObj(psInfo.chan, psObj) == -1) {
 		goto channelWriteFailed;
@@ -1185,7 +1185,7 @@ GetPostscriptPoints(
  *--------------------------------------------------------------
  */
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 
 /*
@@ -1195,15 +1195,15 @@ GetPostscriptPoints(
  #define GetBValue(rgb)	((BYTE)((rgb)>>16))
  */
 
-#else /* !WIN32 */
+#else /* !_WIN32 */
 
 #define GetRValue(rgb)	((rgb & cdata->red_mask) >> cdata->red_shift)
 #define GetGValue(rgb)	((rgb & cdata->green_mask) >> cdata->green_shift)
 #define GetBValue(rgb)	((rgb & cdata->blue_mask) >> cdata->blue_shift)
 
-#endif /* WIN32 */
+#endif /* _WIN32 */
 
-#if defined(WIN32) || defined(MAC_OSX_TK)
+#if defined(_WIN32) || defined(MAC_OSX_TK)
 static void
 TkImageGetColor(
     TkColormapData *cdata,	/* Colormap data */
@@ -1215,7 +1215,7 @@ TkImageGetColor(
     *green = (double) GetGValue(pixel) / 255.0;
     *blue  = (double) GetBValue(pixel) / 255.0;
 }
-#else /* ! (WIN32 || MAC_OSX_TK) */
+#else /* ! (_WIN32 || MAC_OSX_TK) */
 static void
 TkImageGetColor(
     TkColormapData *cdata,	/* Colormap data */
@@ -1237,7 +1237,7 @@ TkImageGetColor(
 	*blue  = cdata->colors[pixel].blue / 65535.0;
     }
 }
-#endif /* WIN32 || MAC_OSX_TK */
+#endif /* _WIN32 || MAC_OSX_TK */
 
 /*
  *--------------------------------------------------------------
