@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2014
+// Copyright (C) 1999-2015
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -6,7 +6,6 @@
 #define __tkmacosx_h__
 
 #include <tcl.h>
-#include <tkMacOSXPrivate.h>
 
 #include <vector.h>
 
@@ -14,31 +13,30 @@ class TkMacosx {
  private:
   Tcl_Interp* interp;
 
+  /*
   int showDialog;
 
-  OSStatus status;
   CGContextRef context;
+  Matrix canvasToPage;
+
+  OSStatus status;
   PMPageFormat pageFormat;
   PMPrintSettings printSettings;
   PMPrintSession printSession;
 
-  Matrix canvasToPage;
-
   int pmPrint(int, const char**);
   int pmPrintBegin(int, const char**);
   int pmPrintEnd();
-
   int pmPrintText(int, const char**);
-
   int pmPageSetup();
-
+  */
  public:
   TkMacosx(Tcl_Interp*);
   ~TkMacosx();
 
-  int pm(int, const char**);
+  //  int pm(int, const char**);
   int locale(int, const char**);
-
+  /*
   const Matrix& getCanvasToPage() {return canvasToPage;}
 
   void begin();
@@ -58,6 +56,7 @@ class TkMacosx {
   void fillPolygon(float*, float*, int);
   
   void bitmapCreate(void*, int, int, float, float, float, float);
+  */
 };
 
 extern TkMacosx* tkmacosx;
