@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2014
+// Copyright (C) 1999-2015
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -22,14 +22,18 @@ TkMacosx* tkmacosx=NULL;
 
 int Tkmacosx_Init(Tcl_Interp* interp) {
 
-  // Define Package Name
-  if (Tcl_PkgProvide(interp, "Tkmacosx", "1.0") == TCL_ERROR)
+  if (Tcl_InitStubs(interp, TCL_PATCH_LEVEL, 0) == NULL)
+    return TCL_ERROR;
+
+  if (Tk_InitStubs(interp, TK_PATCH_LEVEL, 0) == NULL)
     return TCL_ERROR;
 
-  // Commands
   Tcl_CreateCommand(interp, "macosx", TkmacosxCmd,
 		    (ClientData)NULL, (Tcl_CmdDeleteProc *)NULL);
 
+  if (Tcl_PkgProvide(interp, PACKAGE_NAME, PACKAGE_VERSION))
+    return TCL_ERROR;
+
   tkmacosx = new TkMacosx(interp);
 
   if (tkmacosx)
@@ -41,8 +45,10 @@ int Tkmacosx_Init(Tcl_Interp* interp) {
 int TkmacosxCmd(ClientData data,Tcl_Interp *interp,int argc,const char* argv[])
 {
   if (argc>=2) {
+/*
     if (!strncmp(argv[1], "pm", 2))
       return tkmacosx->pm(argc, argv);
+*/
     if (!strncmp(argv[1], "locale", 2))
       return tkmacosx->locale(argc, argv);
     else {
@@ -51,7 +57,7 @@ int TkmacosxCmd(ClientData data,Tcl_Interp *interp,int argc,const char* argv[])
     }
   }
   else {
-    Tcl_AppendResult(interp, "usage: macosx ?pm?locale?", NULL);
+    Tcl_AppendResult(interp, "usage: macosx ?locale?", NULL);
     return TCL_ERROR;
   }
 }
@@ -60,6 +66,7 @@ TkMacosx::TkMacosx(Tcl_Interp* intp)
 {
   interp = intp;
 
+/*
   showDialog = 0;
 
   status = noErr;
@@ -67,14 +74,17 @@ TkMacosx::TkMacosx(Tcl_Interp* intp)
   printSettings = kPMNoPrintSettings;
   printSession = NULL;
   context = NULL;
+*/
 }
 
 TkMacosx::~TkMacosx()
 {
+/*
   if (pageFormat != kPMNoPageFormat)
     PMRelease(pageFormat);
   if (printSettings != kPMNoPrintSettings)
     PMRelease(printSettings);
+*/
 }
 
 // Locale
@@ -104,6 +114,7 @@ int TkMacosx::locale(int argc, const char* argv[])
   return TCL_OK;
 }
 
+/*
 // Image Print Mangager
 int TkMacosx::pm(int argc, const char* argv[])
 {
@@ -178,7 +189,6 @@ int TkMacosx::pmPrintBegin(int argc, const char* argv[])
 
   Vector canvas(width,height);
 
-  /*
   // print session
   status = PMCreateSession(&printSession);
   if (status != noErr)
@@ -348,13 +358,10 @@ int TkMacosx::pmPrintBegin(int argc, const char* argv[])
  error:
   cerr << "PM Error Code: " << status << endl;
   return TCL_ERROR;
-  */
-  return TCL_OK;
 }
 
 int TkMacosx::pmPrintEnd()
 {
-  /*
   status = PMSessionEndPage(printSession);
   if (status != noErr)
     goto error;
@@ -376,13 +383,10 @@ int TkMacosx::pmPrintEnd()
   PMRelease(printSession);
   printSession = NULL;
   return TCL_ERROR;
-  */
-  return TCL_OK;
 }
 
 int TkMacosx::pmPrintText(int argc, const char* argv[])
 {
-  /*
   const int fontSize =12;
   const float margin =36;
 
@@ -646,13 +650,10 @@ int TkMacosx::pmPrintText(int argc, const char* argv[])
     delete sstr;
 
   return TCL_ERROR;
-  */
-  return TCL_OK;
 }
 
 int TkMacosx::pmPageSetup()
 {
-  /*
   // print session
   status = PMCreateSession(&printSession);
   if (status != noErr)
@@ -692,8 +693,6 @@ int TkMacosx::pmPageSetup()
   PMRelease(printSession);
   printSession = NULL;
   return TCL_ERROR;
-  */
-  return TCL_OK;
 }
 
 // drawing routines
@@ -726,7 +725,7 @@ void TkMacosx::dash(float* dd, int nn)
 
 void TkMacosx::font(const char* font, float size)
 {
-//  CGContextSelectFont(context, font, size, kCGEncodingMacRoman);
+  CGContextSelectFont(context, font, size, kCGEncodingMacRoman);
 }
 
 void TkMacosx::clip(float x, float y, float w, float h)
@@ -743,7 +742,7 @@ void TkMacosx::drawText(float x, float y, float angle, const char* text)
   CGContextSetTextMatrix(context, mm);
 
   CGContextSetTextDrawingMode (context, kCGTextFill);
-//  CGContextShowTextAtPoint (context, x, y, text, strlen(text));
+  CGContextShowTextAtPoint (context, x, y, text, strlen(text));
 }
 
 void TkMacosx::drawLines(float* x, float* y, int n)
@@ -809,3 +808,4 @@ void TkMacosx::bitmapCreate(void* data, int width, int height,
   if (cs)
     CGColorSpaceRelease(cs);
 }
+*/
